summaryrefslogtreecommitdiffstats
path: root/libavcodec/acelp_vectors.h
diff options
context:
space:
mode:
authorDiego Biurrun <diego@biurrun.de>2008-05-26 23:36:05 +0000
committerDiego Biurrun <diego@biurrun.de>2008-05-26 23:36:05 +0000
commit1384e2705470e9603a2ed2fdaff801a9cc6b2758 (patch)
treeb78652e74870075bab6e10ad73c01133d2c4cdf1 /libavcodec/acelp_vectors.h
parent5231f101d156bbc6000f0555cf80abc3d966a814 (diff)
downloadffmpeg-streaming-1384e2705470e9603a2ed2fdaff801a9cc6b2758.zip
ffmpeg-streaming-1384e2705470e9603a2ed2fdaff801a9cc6b2758.tar.gz
consistency cosmetics: indices --> indexes in variable names
Originally committed as revision 13446 to svn://svn.ffmpeg.org/ffmpeg/trunk
Diffstat (limited to 'libavcodec/acelp_vectors.h')
-rw-r--r--libavcodec/acelp_vectors.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libavcodec/acelp_vectors.h b/libavcodec/acelp_vectors.h
index 53901a9..ba865e9 100644
--- a/libavcodec/acelp_vectors.h
+++ b/libavcodec/acelp_vectors.h
@@ -105,7 +105,7 @@ extern const uint8_t ff_fc_2pulses_9bits_track2_gray[32];
* \param fc_v [out] decoded fixed codebook vector (2.13)
* \param tab1 table used for first pulse_count pulses
* \param tab2 table used for last pulse
* \param pulse_indices fixed codebook indexes
* \param pulse_signs signs of the excitation pulses (0 bit value
* means negative sign)
* \param bits number of bits per one pulse index
@@ -118,7 +118,7 @@ void ff_acelp_fc_pulse_per_track(
int16_t* fc_v,
const uint8_t *tab1,
const uint8_t *tab2,
- int pulse_indices,
+ int pulse_indexes,
int pulse_signs,
int pulse_count,
int bits);
@@ -105,7 +105,7 @@ extern const uint8_t ff_fc_2pulses_9bits_track2_gray[32];
* \param tab1 table used for first pulse_count pulses
* \param tab2 table used for last pulse
- * \param pulse_indices fixed codebook indexes
+ * \param pulse_indexes fixed codebook indexes
* \param pulse_signs signs of the excitation pulses (0 bit value
* means negative sign)
OpenPOWER on IntegriCloud